@@ -264,7 +264,11 @@ previous character before moving to the previous long word."
   "Kill current region or current point."
   (interactive)
   (if (use-region-p)
-      (kill-region (region-beginning) (region-end))
+      (progn
+        ;; Ensure complete line selections remove newline characters.
+        (when (and (eolp) (<= (region-beginning) (pos-bol)))
+          (forward-visible-line 1))
+        (kill-region (region-beginning) (region-end)))
     (delete-char 1))
   (helix--clear-data))
 
